# autogenerated module
from dataclasses import dataclass, field
from typing import List

from ..core.dataclasses_dict import DataclassDictMixIn



@dataclass
class Info(DataclassDictMixIn):
    """Info contains versioning information. how we'll want to distribute that
      information.

      **parameters**

      * **buildDate** ``str`` - 
      * **compiler** ``str`` - 
      * **gitCommit** ``str`` - 
      * **gitTreeState** ``str`` - 
      * **gitVersion** ``str`` - 
      * **goVersion** ``str`` - 
      * **major** ``str`` - 
      * **minor** ``str`` - 
      * **platform** ``str`` - 
    """
    buildDate: 'str'
    compiler: 'str'
    gitCommit: 'str'
    gitTreeState: 'str'
    gitVersion: 'str'
    goVersion: 'str'
    major: 'str'
    minor: 'str'
    platform: 'str'


